#@TYPE: Platform template
#@NAME: stm32mp-t1000-common
#@DESCRIPTION: Common machine configuration for t1000 hardware platform
#@NEEDED_BSPLAYERS: meta-st-stm32mp

PREFERRED_PROVIDER_virtual/kernel = "linux-stm32mp"
PREFERRED_VERSION_linux-stm32mp ?= "4.19"
PREFERRED_PROVIDER_virtual/bootloader = "u-boot-stm32mp"
PREFERRED_VERSION_u-boot-stm32mp ?= "2018.11"

include conf/machine/include/st-machine-common-stm32mp.inc
# =========================================================================
# Remove obsolete settings from ST
# =========================================================================
MACHINE_EXTRA_RRECOMMENDS_remove = " linux-examples-stm32mp1 "
MACHINE_EXTRA_RRECOMMENDS_remove = " m4projects-stm32mp1 "
INHERIT_remove = " flashlayout-stm32mp "
EXTRA_IMAGEDEPENDS_remove = "sdcard-raw-tools-native"
IMAGE_CLASSES_remove = "image_types-stubi"

# Do not yet remove st-partitions-image because it is needed for image-stm32mp-* images
#IMAGE_CLASSES_remove = "st-partitions-image"
UBOOT_SPLASH_IMAGE = ""

# If required extra partitions are defined in main rootfs image, not in machine
PARTITIONS_IMAGE = ""
PARTITIONS_MOUNTPOINT_IMAGE = ""

# We don't use STs UBI image generation options
ENABLE_MULTIVOLUME_UBI="0"

# =========================================================================
# Machine settings
# =========================================================================
# Define specific common layer name
MACHINEOVERRIDES =. "stm32mp-t10xx:"

# Extend machine feature
MACHINE_FEATURES += "${@'gpu' if d.getVar('ACCEPT_EULA_'+d.getVar('MACHINE', True), True) == '1' else ''}"

# Default serial consoles (TTYs) to enable using getty
SERIAL_CONSOLES = "115200;ttySTM0"
SERIAL_CONSOLE = "115200 ttySTM0"

# We have no soundcard (yet). So remove configuration and current settings file
# from OpenST for alsa
MACHINE_EXTRA_RRECOMMENDS_remove = "alsa-state-stm32mp1"

# What should be built alongside this image
EXTRA_IMAGEDEPENDS += "tf-a-stm32mp"
EXTRA_IMAGEDEPENDS += "u-boot-stm32mp"

# Chip architecture
DEFAULTTUNE = "cortexa7thf-neon-vfpv4"
include conf/machine/include/tune-cortexa7.inc

# Kernel settings
ST_KERNEL_LOADADDR   = "0xC2000040"


# =========================================================================
# License settings
# =========================================================================

# Enable licence summary and configure License content generation
ENABLE_IMAGE_LICENSE_SUMMARY = "1"
IMAGE_SUMMARY_LIST = "#IMAGE#:${STM32MP_USERFS_IMAGE}"

# =========================================================================
# Common Extlinux boot settings
# =========================================================================
# Define boot command lines
#
# The following bootschemes are supported
# - boot from sdcard (BOOTPIN_0,2=1, BOOTPIN_1=0)
# - boot from nor (BOOTPIN_0=1, BOOTPIN_3,2=0)
#   When booting from nor u-boot variable 'boot_targets' select where to find
#   the bootfs with EXTLINUX configuration
#

# Add extlinux definintions for boards
UBOOT_EXTLINUX_TIMEOUT = "-1"
UBOOT_EXTLINUX_KERNEL_IMAGE = "/boot/${KERNEL_IMAGETYPE}"
UBOOT_EXTLINUX_CONFIG_FLAGS = "sdcard nor-emmc nor-nand"


# =========================================================================
# Specific features settings
# =========================================================================
# OPTEE
OPTEE_OS_WITH_PAGER = "n"


# =========================================================================
# Settings to forward to distro
# =========================================================================
# If swupdate layer is used we want to use libubootenv as provider. Else
# we should use it from openembedded-core or poky. This isn't yet implemented
# by this code. It should be integrated in the distro and activated e.g. by
# swupdate DISTRO_FEATURE. This requires the layers to contain meta-swupdate
# which isn't true for all supported platfoms currently.
# The best would be to include PREFERRED_PROVIDER_u-boot-fw-utils ??= "libubootenv"
# in the layer.conf file of meta-swupdate.
#
# So the workaround is to include it here
PREFERRED_PROVIDER_u-boot-fw-utils = "libubootenv"


